package com.sky.ioc.controller.user;

import com.sky.ioc.entity.domain.system.Role;
import com.sky.ioc.service.user.RoleService;
import com.sky.ioc.service.user.UserService;
import com.sky.ioc.tool.ReturnMsg;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@Api(tags = "系统--角色管理")
@Slf4j
@RestController
@RequestMapping("/role")
public class RoleController {


    @Autowired
    private RoleService roleService;

    @Autowired
    private UserService userService;

    @ApiOperation("获取角色列表")
    @GetMapping("/role_list")
    public ReturnMsg getRoleList(@RequestParam(required = false) String page, @RequestParam(required = false) String page_size) {
        return roleService.getRoleList(page, page_size);
    }

    @ApiOperation("获取角色详情")
    @GetMapping("/role")
    public ReturnMsg getRole(@RequestParam("role_id") String role_id) {
        return roleService.getRoleById(role_id);
    }

    @ApiOperation("添加角色")
    @PostMapping("/role")
    public ReturnMsg addRole(Role role) {
        return roleService.addRole(role);
    }

    @ApiOperation("修改角色")
    @PutMapping("/role")
    public ReturnMsg updateRole(Role role) {
        return roleService.updateRole(role);
    }

    @ApiOperation("删除角色")
    @DeleteMapping("/role")
    public ReturnMsg delRole(@RequestParam("role_id") String role_id) {
        return roleService.deleteRole(role_id);
    }

    @ApiOperation("批量删除角色")
    @DeleteMapping("/batch_delete_role")
    public ReturnMsg batchDelRole(@RequestParam("role_ids") String role_ids) {
        roleService.batchDelRole(role_ids);
        return null;
    }

    @ApiOperation("获取角色成员")
    @GetMapping("/member")
    public ReturnMsg getMember(@RequestParam("role_id") String role_id,
                               @RequestParam(required = false) String page, @RequestParam(required = false) String page_size) {
        return userService.getUserListByRole(role_id, page, page_size);
    }

    @ApiOperation("移除角色成员")
    @PutMapping("/member")
    public ReturnMsg removeMember(@RequestParam("user_id") String user_id, @RequestParam("role_id") String role_id) {
        return roleService.removeMember(user_id, role_id);
    }

    @ApiOperation("批量移除角色成员")
    @DeleteMapping("/batch_delete_role_member")
    public ReturnMsg batchRemoveMember(@RequestParam("users_id") String users_id, @RequestParam("role_id") String role_id) {
        return roleService.batchRemoveMember(users_id, role_id);
    }

}
